"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api = require("../../../api");
const Channel_1 = require("../../../Channel");
exports.parameters = [
    {
        in: "path",
        name: "type",
        type: "string",
        enum: ["GR", "BS", "CS", "SKY"],
        required: true
    },
    {
        in: "path",
        name: "channel",
        type: "string",
        required: true
    }
];
exports.get = (req, res) => {
    const channel = Channel_1.default.get(req.params.type, req.params.channel);
    if (channel === null) {
        api.responseError(res, 404);
        return;
    }
    const body = channel.export();
    body.services = channel.getServices().map(service => ({
        id: service.id,
        serviceId: service.serviceId,
        networkId: service.networkId,
        name: service.name
    }));
    res.json(body);
};
exports.get.apiDoc = {
    tags: ["channels"],
    operationId: "getChannel",
    responses: {
        200: {
            description: "OK",
            schema: {
                $ref: "#/definitions/Channel"
            }
        },
        404: {
            description: "Not Found",
            schema: {
                $ref: "#/definitions/Error"
            }
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};

//# sourceMappingURL={channel}.js.map
