"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api = require("../../../../../api");
const Channel_1 = require("../../../../../Channel");
const Service_1 = require("../../../../../Service");
exports.parameters = [
    {
        in: "path",
        name: "type",
        type: "string",
        enum: ["GR", "BS", "CS", "SKY"],
        required: true
    },
    {
        in: "path",
        name: "channel",
        type: "string",
        required: true
    },
    {
        in: "path",
        name: "id",
        type: "integer",
        maximum: 6553565535,
        required: true
    }
];
exports.get = (req, res) => {
    const channel = Channel_1.default.get(req.params.type, req.params.channel);
    if (channel === null) {
        api.responseError(res, 404);
        return;
    }
    const service = Service_1.default.findByChannel(channel).find(sv => (sv.id === req.params.id || sv.serviceId === req.params.id));
    if (!service) {
        api.responseError(res, 404);
        return;
    }
    res.redirect(307, `/api/services/${service.id}`);
};
exports.get.apiDoc = {
    tags: ["channels", "services"],
    operationId: "getServiceByChannel",
    responses: {
        200: {
            description: "OK",
            schema: {
                type: "array",
                items: {
                    $ref: "#/definitions/Service"
                }
            }
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};

//# sourceMappingURL={id}.js.map
